/v1/projects/{project_id}/commit — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Project »

# /v1/projects/{project_id}/commit

Contents

- /v1/projects/{project_id}/commit
  - POST /v1/projects/{project_id}/commit
    - Parameters
    - Response status codes

## POST /v1/projects/{project_id}/commit

Write changes on disk

### Parameters

- project_id: The UUID of the project

### Response status codes

- 404: The project doesn’t exist
- 204: Changes have been written on disk

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »
- Project »